library("vsn")
library("genefilter")

if(!exists("a") ) load("a.rda")

if(!exists("probeAnno") ) load("probeAnno-mummer.rda")

rrr = 1
hybeSets = list(
  "seg-pombe-polyA" =
     c("ivt1.CEL",
       "ivt2.CEL",
       "ivt3.CEL"))[rrr]

normMethod = c("vsn", "shiftlog")[rrr]
names(normMethod) = names(hybeSets)

jref = which(a$NucleicAcid == "DNA")
stopifnot(length(jref)==3)

if(!exists("allPM")) {

  chrstr = paste(rep(1:3, each=2), rep(c("+", "-"), 3), sep=".")

  allPM = unique(unlist(lapply(chrstr, function(chr) 
    get(paste(chr, "index", sep="."), probeAnno))))
  
  allPM = allPM[ probeAnno$probeReverse$no_feature[allPM]=="no" &
    probeAnno$probeDirect$no_feature[allPM]=="no" ]
  
  cat("Selected", length(allPM), "intergenic PM probes.\n")

}

if(!exists("refSigPM")) {

  refSig    = rowMeans(log(exprs(a)[, jref, drop=FALSE], 2))
  refSigPM  = refSig[allPM]
  
  nrStrata  = 20
  quants    = quantile(refSig, probs=seq(0, 1, length=nrStrata+1))
  quants[1] = quants[1]-1
  strata    = cut(refSigPM, quants)

}

for(hs in seq(along=hybeSets) ) {

  outdir = names(hybeSets)[hs]
  cat(outdir, "\n")
  fn = hybeSets[[hs]]
  
  x.bg  = tapply(refSigPM, strata, median)
  y.bg  = matrix(NA, nrow=length(x.bg), ncol=length(fn))

  bgfun = vector(mode="list", length=length(fn))
  colnames(y.bg) = names(bgfun) = fn

  for(f in fn) {
    y.bg[,f]   = tapply(log(exprs(a)[allPM, f], 2), strata, shorth)
    bgfun[[f]] = approxfun(x.bg, y.bg[,f], rule=2)
  }    

  matplot(x.bg, y.bg, pch=15+seq(along=fn))
  px = seq(5, 13, by=0.1)

  for(bf in bgfun)
    lines(px, bf(px))
  
  yn = matrix(NA, nrow=nrow(exprs(a)), ncol=length(fn))
  colnames(yn) = fn

  for(f in fn)
    yn[, f] = (exprs(a)[, f] - 2^bgfun[[f]](refSig) ) / 2^refSig

  ## vsn with strata? Not sure whether this is useful
  ## vsr = vsn(yn, lts.quantile=0.95, strata=as.integer(strata), subsample=1e5)

  switch(normMethod[hs],
       vsn = {
         ## vsn without strata
         xn = vsn(yn, lts.quantile=0.95, subsample=2e5)
         exprs(xn)    = exprs(xn)/log(2)
         pData(xn) = pData(a)[fn, ]
       },
       shiftlog = {
         offset = 0.5
         stopifnot(!any(yn+offset <= 0))
         xn = new("exprSet", exprs = log(yn+offset, 2), phenoData=phenoData(a)[fn, ])
       },
       stop("Zapperlot")
  )

  save(xn, refSig, file=file.path(outdir, "xn.rda"), compress=TRUE)
}
