library("affy")
library("tilingArray")

nc = as.integer(1612) # 2560 for Sce

PMind = rep(seq(as.integer(1), nc - as.integer(3), by = as.integer(2)),each = nc) * nc + (1:nc)
MMind = PMind + nc
ispm = rep(FALSE, nc * nc)
ispm[PMind] = TRUE

d1 = readCel2eSet("sbw_genomic_dnase1.cel")
d2 = readCel2eSet("sbw_genomic_dnase2.cel")
d3 = readCel2eSet("sbw_genomic_dnase3.cel")

t1 = readCel2eSet("sbw_tot_poly1.cel")
t2 = readCel2eSet("sbw_tot_poly1.cel")

dl1 = log(exprs(d1), 2)
dl2 = log(exprs(d2), 2)
dl3 = log(exprs(d3), 2)

tl1 = log(exprs(t1), 2)
tl2 = log(exprs(t2), 2)

s_pombe_seq_gc = read.table("s_pombe_seq_gc.txt", sep = "\t", header=TRUE, as.is=TRUE, quote="")

tmp = which(s_pombe_seq_gc$gc_pct > 30)
PMind_30 = PMind[tmp][!is.na(PMind[tmp])]
MMind_30 = MMind[tmp][!is.na(PMind[tmp])]

dl1_pm = dl1[PMind_30]
dl1_mm = dl1[MMind_30]

dl2_pm = dl2[PMind_30]
dl2_mm = dl2[MMind_30]

dl3_pm = dl3[PMind_30]
dl3_mm = dl3[MMind_30]

tl1_pm = tl1[PMind_30]
tl1_mm = tl1[MMind_30]

tl2_pm = tl2[PMind_30]
tl2_mm = tl2[MMind_30]

dl1_pm = dl1[PMind]
dl1_mm = dl1[MMind]

dl2_pm = dl2[PMind]
dl2_mm = dl2[MMind]

dl3_pm = dl3[PMind]
dl3_mm = dl3[MMind]

tl1_pm = tl1[PMind]
tl1_mm = tl1[MMind]

tl2_pm = tl2[PMind]
tl2_mm = tl2[MMind]

jpeg(filename = "pombe_scatter.jpg", width = 1500, height = 1000)

#par(mfrow = c(2, 3) )
opar <- par(mfrow = c(2, 3), mex = 0.8, mar = c(6, 6, 5, 2) + .1)

smoothScatter(dl1_pm, dl1_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 1")
abline(0,1, col = "red")

smoothScatter(dl2_pm, dl2_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 2")
abline(0,1, col = "red")

smoothScatter(dl3_pm, dl3_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 3")
abline(0,1, col = "red")

smoothScatter(tl1_pm, tl1_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Greens")), xlab="log2 PM", ylab="log2 MM")
title("RNA Hyb 1")
abline(0,1, col = "red")

smoothScatter(tl2_pm, tl2_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Greens")), xlab="log2 PM", ylab="log2 MM")
title("RNA Hyb 2")
abline(0,1, col = "red")

dev.off()

dl1_pm_h = hist(dl1_pm, breaks=100, plot=FALSE)
dl1_mm_h = hist(dl1_mm, breaks=100, plot=FALSE)
dl2_pm_h = hist(dl2_pm, breaks=100, plot=FALSE)
dl2_mm_h = hist(dl2_mm, breaks=100, plot=FALSE)
dl3_pm_h = hist(dl3_pm, breaks=100, plot=FALSE)
dl3_mm_h = hist(dl3_mm, breaks=100, plot=FALSE)

tl1_pm_h = hist(tl1_pm, breaks=100, plot=FALSE)
tl1_mm_h = hist(tl1_mm, breaks=100, plot=FALSE)
tl2_pm_h = hist(tl2_pm, breaks=100, plot=FALSE)
tl2_mm_h = hist(tl2_mm, breaks=100, plot=FALSE)

# See functions below!

jpeg(filename = "pombe_hists.jpg", width = 1500, height = 1000)

#par(mfrow = c(2, 3) )
opar <- par(mfrow = c(2, 3), mex = 0.8, mar = c(6, 6, 5, 2) + .1)

hist2v2(dl1_pm_h, dl1_mm_h)
title("DNA Hyb 1")

hist2v2(dl2_pm_h, dl2_mm_h)
title("DNA Hyb 2")

hist2v2(dl3_pm_h, dl3_mm_h)
title("DNA Hyb 3")


hist2v2(tl1_pm_h, tl1_mm_h)
title("RNA Hyb 1")

hist2v2(tl2_pm_h, tl2_mm_h)
title("RNA Hyb 2")

dev.off()


# Others

f1=file("index_pm_bin1.txt")
PM = as.integer(readLines(f1))

f2=file("index_mm_bin1.txt")
MM = as.integer(readLines(f2))

x1=log(exprs(a)[PM],2)
x2=log(exprs(a)[MM],2)

smoothScatter(x1,x2,nrpoints=0)
abline(0,1)

# Overlay hists

x <- rnorm(100)
y <- rnorm(100)
xh = hist(x, plot=FALSE)
yh = hist(y, plot=FALSE)

hist2v <-
function(xh, yh) {
   plot.new()
   plot.window(xlim=range(xh$breaks, yh$breaks),
               ylim=range(0, xh$density, yh$density))
   rect(xh$breaks[-length(xh$breaks)], 0,
        xh$breaks[-1], xh$density, border="blue")
   rect(yh$breaks[-length(yh$breaks)], 0,
        yh$breaks[-1], yh$density, border="red")
   axis(1)
   axis(2)
}

# Or:

hist2v2 <-
function(xh, yh) {
   plot.new()
   plot.window(xlim=range(xh$breaks, yh$breaks),
               ylim=range(0, xh$density, yh$density))
   nx = length(xh$density)
   ny = length(yh$density)
   lines(rep(xh$breaks, c(1, rep(2, nx - 1), 1)),
         rep(xh$density, each = 2), col = "red")
   lines(rep(yh$breaks, c(1, rep(2, ny - 1), 1)),
         rep(yh$density, each = 2), col = "blue")
   axis(1)
   axis(2)
   legend(max(xh$breaks, yh$breaks) - 4, 5*max(xh$density, yh$density)/6, c("MM", "PM"), col=c(4,2), lty = c(1, 1), bty = "n")
}

# Do it!
hist2v(xh, yh)


# Sce stuff

library("davidTiling")
data("davidTiling")

nc = as.integer(2560)

PMind = rep(seq(as.integer(1), nc - as.integer(3), by = as.integer(2)),each = nc) * nc + (1:nc)
MMind = PMind + nc
ispm = rep(FALSE, nc * nc)
ispm[PMind] = TRUE

a1 = log(exprs(davidTiling)[,1],2)
a2 = log(exprs(davidTiling)[,2],2)
a3 = log(exprs(davidTiling)[,3],2)
a4 = log(exprs(davidTiling)[,4],2)
a5 = log(exprs(davidTiling)[,5],2)
a6 = log(exprs(davidTiling)[,6],2)
a7 = log(exprs(davidTiling)[,7],2)
a8 = log(exprs(davidTiling)[,8],2)

a1_pm = a1[PMind]
a1_mm = a1[MMind]

a2_pm = a2[PMind]
a2_mm = a2[MMind]

a3_pm = a3[PMind]
a3_mm = a3[MMind]

a4_pm = a4[PMind]
a4_mm = a4[MMind]

a5_pm = a5[PMind]
a5_mm = a5[MMind]

a6_pm = a6[PMind]
a6_mm = a6[MMind]

a7_pm = a7[PMind]
a7_mm = a7[MMind]

a8_pm = a8[PMind]
a8_mm = a8[MMind]

jpeg(filename = "yeast_scatter.jpg", width = 1500, height = 1000)

opar <- par(mfrow = c(3, 4), mex = 0.8, mar = c(6, 6, 5, 2) + .1)
#par(mfrow = c(3, 3) )

smoothScatter(a1_pm, a1_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 1")
abline(0,1, col = "red")

smoothScatter(a2_pm, a2_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 2")
abline(0,1, col ="red")

smoothScatter(a3_pm, a3_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Blues")), xlab="log2 PM", ylab="log2 MM")
title("DNA Hyb 3")
abline(0,1, col ="red")

plot.new()

smoothScatter(a4_pm, a4_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Greens")), xlab="log2 PM", ylab="log2 MM")
title("Poly(A) RNA Hyb 1")
abline(0,1, col ="red")

smoothScatter(a5_pm, a5_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Greens")), xlab="log2 PM", ylab="log2 MM")
title("Poly(A) RNA Hyb 2")
abline(0,1, col ="red")

smoothScatter(a6_pm, a6_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Greens")), xlab="log2 PM", ylab="log2 MM")
title("Poly(A) RNA Hyb 3")
abline(0,1, col ="red")

plot.new()

smoothScatter(a7_pm, a7_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Oranges")), xlab="log2 PM", ylab="log2 MM")
title("Total RNA Hyb 1")
abline(0,1, col ="red")

smoothScatter(a8_pm, a8_mm, nrpoints=0, colramp=colorRampPalette(RColorBrewer::brewer.pal(9, "Oranges")), xlab="log2 PM", ylab="log2 MM")
title("Total RNA Hyb 2")
abline(0,1, col ="red")

dev.off()


a1_pm_h = hist(a1_pm, breaks=100, plot=FALSE)
a1_mm_h = hist(a1_mm, breaks=100, plot=FALSE)
a2_pm_h = hist(a2_pm, breaks=100, plot=FALSE)
a2_mm_h = hist(a2_mm, breaks=100, plot=FALSE)
a3_pm_h = hist(a3_pm, breaks=100, plot=FALSE)
a3_mm_h = hist(a3_mm, breaks=100, plot=FALSE)
a4_pm_h = hist(a4_pm, breaks=100, plot=FALSE)
a4_mm_h = hist(a4_mm, breaks=100, plot=FALSE)
a5_pm_h = hist(a5_pm, breaks=100, plot=FALSE)
a5_mm_h = hist(a5_mm, breaks=100, plot=FALSE)
a6_pm_h = hist(a6_pm, breaks=100, plot=FALSE)
a6_mm_h = hist(a6_mm, breaks=100, plot=FALSE)
a7_pm_h = hist(a7_pm, breaks=100, plot=FALSE)
a7_mm_h = hist(a7_mm, breaks=100, plot=FALSE)
a8_pm_h = hist(a8_pm, breaks=100, plot=FALSE)
a8_mm_h = hist(a8_mm, breaks=100, plot=FALSE)

jpeg(filename = "yeast_hists.jpg", width = 1500, height = 1000)

opar <- par(mfrow = c(3, 4), mex = 0.8, mar = c(6, 6, 5, 2) + .1)
#par(mfrow = c(3, 3) )

hist2v2(a1_pm_h, a1_mm_h)
title("DNA Hyb 1")

hist2v2(a2_pm_h, a2_mm_h)
title("DNA Hyb 1")

hist2v2(a3_pm_h, a3_mm_h)
title("DNA Hyb 1")

plot.new()

hist2v2(a4_pm_h, a4_mm_h)
title("Poly(A) RNA Hyb 1")

hist2v2(a5_pm_h, a5_mm_h)
title("Poly(A) RNA Hyb 2")

hist2v2(a6_pm_h, a6_mm_h)
title("Poly(A) RNA Hyb 3")

plot.new()

hist2v2(a7_pm_h, a7_mm_h)
title("Total RNA Hyb 1")

hist2v2(a8_pm_h, a8_mm_h)
title("Total RNA Hyb 2")

dev.off()


isRNA = davidTiling$nucleicAcid %in% c("poly(A) RNA", "total RNA")
isDNA = davidTiling$nucleicAcid %in% "genomic DNA"
